@@ -1,7 +1,7 @@
 package App::wordlist;
 
-our $DATE = '2016-04-15'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,7 +24,14 @@ sub _list_installed {
         my $wl = $wl0;
 
         my $type;
-        if ($wl =~ s/^Char:://) {
+        if ($wl =~ /^(Base|MetaSyntactic)\z/) {
+            # just a base class
+            next;
+        } elsif ($wl =~ s/^Base:://) {
+            $type = 'Base';
+        } elsif ($wl =~ s/^MetaSyntactic:://) {
+            $type = 'MetaSyntactic';
+        } elsif ($wl =~ s/^Char:://) {
             $type = 'Char';
         } elsif ($wl =~ s/^Phrase:://) {
             $type = 'Phrase';
@@ -136,7 +143,7 @@ wordlists that are not of type `Char` and `Phrase`. `Test` means to only include
 wordlists with names matching `Test::*`.
 
 _
-            schema => ['array*', of => ['str*', in=>['Char', 'Phrase', 'Word', 'Test']]],
+            schema => ['array*', of => ['str*', in=>['Base', 'MetaSyntactic', 'Char', 'Phrase', 'Word', 'Test']]],
             description => <<'_',
 
 By convention, language information is encoded in the wordlist's name. For
@@ -183,6 +190,12 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            argv => [qw/--detail foo/],
+            summary => 'Print wordlist name for each matching words',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
         {
             argv => [qw/-w ID::KBBI foo/],
             summary => 'Select a specific wordlist (multiple -w allowed)',
@@ -381,7 +394,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.24 of App::wordlist (from Perl distribution App-wordlist), released on 2016-04-15.
+This document describes version 0.25 of App::wordlist (from Perl distribution App-wordlist), released on 2016-09-25.
 
 =head1 SYNOPSIS
 
@@ -410,6 +423,10 @@ Examples:
 
  wordlist( arg => ["foo", "bar"], or => 1);
 
+=item * Print wordlist name for each matching words:
+
+ wordlist( arg => ["foo"], detail => 1);
+
 =item * Select a specific wordlist (multiple -w allowed):
 
  wordlist( arg => ["foo"], wordlists => ["ID::KBBI"]);
